@@ -539,6 +539,8 @@ prline (char const *beg, char const *lim, int sep)
 	  char const *b = beg + match_offset;
 	  if (b == lim)
 	    break;
+	  if (match_size == 0)
+	    break;
 	  if(color_option)
 	    printf("\33[%sm", grep_color);
 	  fwrite(b, sizeof (char), match_size, stdout);
@@ -583,13 +585,16 @@ prline (char const *beg, char const *lim, int sep)
 	  lastout = lim;
 	  return;
 	}
-      while ((match_offset = (*execute) (beg, lim - beg, &match_size, 1))
+      while (lim-beg && (match_offset = (*execute) (beg, lim - beg, &match_size, 1))
 	     != (size_t) -1)
 	{
 	  char const *b = beg + match_offset;
 	  /* Avoid matching the empty line at the end of the buffer. */
 	  if (b == lim)
 	    break;
+	  /* Avoid hanging on grep --color "" foo */
+	  if (match_size == 0)
+	    break;
 	  fwrite (beg, sizeof (char), match_offset, stdout);
 	  printf ("\33[%sm", grep_color);
 	  fwrite (b, sizeof (char), match_size, stdout);
@@ -1118,7 +1123,7 @@ Context control:\n\
 With no FILE, or when FILE is -, read standard input.  If less than\n\
 two FILEs given, assume -h.  Exit status is 0 if match, 1 if no match,\n\
 and 2 if trouble.\n"));
-      printf (_("\nReport bugs to <bug-gnu-utils@gnu.org>.\n"));
+      printf (_("\nReport bugs to <bug-grep@gnu.org>.\n"));
     }
   exit (status);
 }
@@ -1519,6 +1524,7 @@ main (int argc, char **argv)
 
       case 'q':
 	exit_on_match = 1;
+	close_stdout_set_status(0);
 	break;
 
       case 'R':
